pyABC
=====

.. figure:: https://raw.githubusercontent.com/ICB-DCM/pyABC/main/doc/logo/logo.svg
   :alt: pyABC logo
   :width: 30 %
   :align: center

|CI| |docs| |codecov| |pypi| |doi| |black|

Massively parallel, distributed and scalable ABC-SMC
(Approximate Bayesian Computation - Sequential Monte Carlo)
for parameter estimation of complex stochastic models.
Implemented in Python with support of the R language.

- **Documentation:** `https://pyabc.readthedocs.io <https://pyabc.readthedocs.io>`_
- **Contact:** `https://pyabc.readthedocs.io/en/latest/about.html <https://pyabc.readthedocs.io/en/latest/about.html>`_
- **Source:** `https://github.com/icb-dcm/pyabc <https://github.com/icb-dcm/pyabc>`_
- **Bug reports:** `https://github.com/icb-dcm/pyabc/issues <https://github.com/icb-dcm/pyabc/issues>`_

Examples
--------

Many examples are available as Jupyter Notebooks in the
`examples directory <https://github.com/icb-dcm/pyabc/tree/main/doc/examples>`_
and also for download and for online inspection in the
`example section of the documentation <http://pyabc.readthedocs.io/en/latest/examples.html>`_.


.. |CI| image:: https://github.com/ICB-DCM/pyABC/workflows/CI/badge.svg
   :target: https://github.com/ICB-DCM/pyABC/actions
   :alt: CI

.. |docs| image:: https://readthedocs.org/projects/pyabc/badge/?version=latest
   :target: http://pyabc.readthedocs.io/en/latest/
   :alt: Docs

.. |codecov| image:: https://codecov.io/gh/ICB-DCM/pyABC/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/ICB-DCM/pyABC
   :alt: Codecov

.. |pypi| image:: https://badge.fury.io/py/pyabc.svg
   :target: https://badge.fury.io/py/pyabc
   :alt: PyPI

.. |doi| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3257587.svg
   :target: https://doi.org/10.5281/zenodo.3257587
   :alt: DOI

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black
